@@ -399,11 +399,17 @@ def to_datetime_str(s: Any = None,
     将 s 先转成 datetime, 然后再转成字符串
 
     :param s: 输入值（可以是字符串或其他类型）
-    :param precision: 小数部分保留的位数（多余部分直接截断）
-    :return: 转换后的 float 值
     """
     r_s = to_datetime(s, pattern=pattern, tz=tz, r_str=False, default_tz=default_tz)
-    return r_s.isoformat() if pattern_str is None else r_s.strftime(pattern_str)
+    if pattern_str is None:
+        iso_str = r_s.isoformat()
+        if '.' in iso_str:
+            parts = iso_str.split('.')
+            # 只保留3位毫秒
+            millisecond_part = parts[1][:3]
+            return parts[0] + '.' + millisecond_part + parts[1][3 + 3:]  # 跳过时区部分
+    else:
+        return r_s.strftime(pattern_str)
 
 
 def to_datetime_format(s: Any = None,
