@@ -1,4 +1,5 @@
 from upplib import *
+from upplib.clean_up_msg import *
 from datetime import datetime, timezone, timedelta
 from typing import Any, Optional, Union
 
@@ -34,24 +35,10 @@ def get_log_msg(contents: dict,
 
 
 def clean_up_msg(msg: str = None, clean_up_type: int = 1) -> str:
-    """
-        2025-09-28T19:38:41.146954-06:00 com.leo.digest.aop.ApiLogAspect - traceId: - (catTraceId:rcs-gateway-0a0f2154-488625-102) - ===>API GatewayFacadeImpl#gatewayRequest START
-        将以上日志格式整理成以下这种
-        2025-09-28T20:09:52.390783-06:00 o.rcs.biz.limiter.XLimitSwitc - rcs-gateway-0a0f2154-488625-102 - xlimit No current limiter configured，key=mobilewalla_mbmultiagents
-    """
     if msg is None:
         return ''
     if clean_up_type == 1:
-        TIME_DEMO = '2025-09-28T20:09:52.390783-06:00'
-        CAT_TRACE_ID_DEMO = '(catTraceId:rcs-gateway-0a0f2154-488625-102)'
-        SEP_S = '- traceId: -'
-        time = msg[0:len(TIME_DEMO)]
-        msg1 = msg[len(TIME_DEMO):].split(SEP_S)
-        method = msg1[0][-31:-2]
-        trace_id = msg1[1][0:len(CAT_TRACE_ID_DEMO) + 1]
-        other = msg1[1][len(trace_id) + 2:].strip()
-        trace_id = re.search(r'\(catTraceId:([^)]+)\)', trace_id).group(1)
-        return f'{time} {method} - {trace_id} - {other}'
+        return clean_up_msg_1(msg)
     return msg
 
 
@@ -105,10 +92,10 @@ def get_rpc_context_seq_id_from_txt(file_name: str = 'a.txt') -> list[str] | Non
 
 
 def get_trace_id_from_txt(file_name: str = 'a.txt',
-                          str_pattern: str = r'catTraceId:([^)]+)'
+                          trace_id_type: int = 0
                           ) -> list[str] | None:
     """
-        2025-09-28T20:09:52.382153-06:00 rcs.biz.aspect.RcsReportAspec (catTraceId:rcs-gateway-0a0f2154-488625-102) - RequestURI:/v1/gateway
+        2025-09-29T14:56:27.411-06:00 rcs.biz.aspect.RcsReportAspec rcs-gateway-0a0f21a6-488646-218 - Rpc-context:{"requester": "yangpu", "seq_id": "yangpu__20250929144002669164", "biz_type": "APPLY"}
         从 txt 文件中获得 trace_id , 去重复以后，返回 list(trace_id)
     """
     trace_id_lines = to_list_from_txt(file_name)
@@ -117,10 +104,14 @@ def get_trace_id_from_txt(file_name: str = 'a.txt',
         return None
     else:
         for trace_id_line in trace_id_lines:
-            trace_id_match = re.search(str_pattern, trace_id_line)
-            trace_id = trace_id_match.group(1) if trace_id_match else None
-            if trace_id:
-                trace_id_ids.add(trace_id)
+            if trace_id_type == 1:
+                try:
+                    if ' - ' in trace_id_line:
+                        trace_id = trace_id_line.split(' - ')[0].split(' ')[-1].strip()
+                        if 15 <= len(trace_id) <= 55 and len(trace_id.split('-')) >= 3:
+                            trace_id_ids.add(trace_id)
+                except Exception as e:
+                    continue
     r_list = list(trace_id_ids)
     r_list.sort()
     return r_list
